@@ -14,7 +14,8 @@
 #'   [grDevices::terrain.colors()] for details.
 #'
 #' An additional set of scales is provided. These scales can act as
-#' [hypsometric (or bathymetric) tints](https://en.wikipedia.org/wiki/Hypsometric_tints).
+#' [hypsometric (or bathymetric)
+#' tints](https://en.wikipedia.org/wiki/Hypsometric_tints).
 #'
 #' - `scale_*_hypso_tint_d()`: For discrete values.
 #' - `scale_*_hypso_tint_c()`: For continuous values.
@@ -39,10 +40,9 @@
 #' @name scale_hypso
 #'
 #' @inheritDotParams ggplot2::discrete_scale breaks:drop
-#' @inheritDotParams ggplot2::continuous_scale breaks:labels na.value
+#' @inheritDotParams ggplot2::continuous_scale breaks:labels
 #' @inheritDotParams ggplot2::binned_scale breaks:limits nice.breaks
-#' @inheritParams ggplot2::scale_fill_viridis_b
-#' @inheritParams ggplot2::continuous_scale
+#' @inheritParams scale_cross_blended
 #' @param palette A valid palette name. The name is matched to the list of
 #'   available palettes, ignoring upper vs. lower case. See
 #'   [hypsometric_tints_db] for more info. Values available are:
@@ -167,12 +167,16 @@
 #'   scale_fill_hypso_tint_d(na.value = "gray10", palette = "dem_poster")
 #' }
 scale_fill_hypso_d <- function(palette = "etopo1_hypso", ...,
-                               alpha = 1, direction = 1) {
+                               alpha = 1, direction = 1,
+                               na.translate = FALSE,
+                               drop = TRUE) {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   ggplot2::discrete_scale(
     aesthetics = "fill",
@@ -182,18 +186,24 @@ scale_fill_hypso_d <- function(palette = "etopo1_hypso", ...,
       direction = direction,
       palette = palette
     ),
+    na.translate = na.translate,
+    drop = drop,
     ...
   )
 }
 #' @export
 #' @rdname scale_hypso
 scale_colour_hypso_d <- function(palette = "etopo1_hypso", ...,
-                                 alpha = 1, direction = 1) {
+                                 alpha = 1, direction = 1,
+                                 na.translate = FALSE,
+                                 drop = TRUE) {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   ggplot2::discrete_scale(
     aesthetics = "colour",
@@ -203,6 +213,8 @@ scale_colour_hypso_d <- function(palette = "etopo1_hypso", ...,
       direction = direction,
       palette = palette
     ),
+    na.translate = na.translate,
+    drop = drop,
     ...
   )
 }
@@ -212,12 +224,14 @@ scale_colour_hypso_d <- function(palette = "etopo1_hypso", ...,
 #' @rdname scale_hypso
 scale_fill_hypso_c <- function(palette = "etopo1_hypso", ...,
                                alpha = 1, direction = 1,
-                               na.value = NA, guide = "colourbar") {
+                               na.value = "transparent", guide = "colourbar") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   length_pal <- nrow(extract_pal(tidyterra::hypsometric_tints_db,
     palette = palette
@@ -240,12 +254,15 @@ scale_fill_hypso_c <- function(palette = "etopo1_hypso", ...,
 #' @rdname scale_hypso
 scale_colour_hypso_c <- function(palette = "etopo1_hypso", ...,
                                  alpha = 1, direction = 1,
-                                 na.value = NA, guide = "colourbar") {
+                                 na.value = "transparent",
+                                 guide = "colourbar") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   length_pal <- nrow(extract_pal(tidyterra::hypsometric_tints_db,
     palette = palette
@@ -268,12 +285,15 @@ scale_colour_hypso_c <- function(palette = "etopo1_hypso", ...,
 #' @rdname scale_hypso
 scale_fill_hypso_b <- function(palette = "etopo1_hypso", ...,
                                alpha = 1, direction = 1,
-                               na.value = NA, guide = "coloursteps") {
+                               na.value = "transparent",
+                               guide = "coloursteps") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   length_pal <- nrow(extract_pal(tidyterra::hypsometric_tints_db,
     palette = palette
@@ -295,12 +315,15 @@ scale_fill_hypso_b <- function(palette = "etopo1_hypso", ...,
 #' @rdname scale_hypso
 scale_colour_hypso_b <- function(palette = "etopo1_hypso", ...,
                                  alpha = 1, direction = 1,
-                                 na.value = NA, guide = "coloursteps") {
+                                 na.value = "transparent",
+                                 guide = "coloursteps") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   length_pal <- nrow(extract_pal(tidyterra::hypsometric_tints_db,
     palette = palette
@@ -386,12 +409,16 @@ hypso.colors <- function(n, palette = "etopo1_hypso",
 #' See **Examples**.
 
 scale_fill_hypso_tint_d <- function(palette = "etopo1_hypso", ...,
-                                    alpha = 1, direction = 1) {
+                                    alpha = 1, direction = 1,
+                                    na.translate = FALSE,
+                                    drop = TRUE) {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   ggplot2::discrete_scale(
     aesthetics = "fill",
@@ -401,18 +428,24 @@ scale_fill_hypso_tint_d <- function(palette = "etopo1_hypso", ...,
       direction = direction,
       palette = palette
     ),
+    na.translate = na.translate,
+    drop = drop,
     ...
   )
 }
 #' @export
 #' @rdname scale_hypso
 scale_colour_hypso_tint_d <- function(palette = "etopo1_hypso", ...,
-                                      alpha = 1, direction = 1) {
+                                      alpha = 1, direction = 1,
+                                      na.translate = FALSE,
+                                      drop = TRUE) {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   ggplot2::discrete_scale(
     aesthetics = "colour",
@@ -422,6 +455,8 @@ scale_colour_hypso_tint_d <- function(palette = "etopo1_hypso", ...,
       direction = direction,
       palette = palette
     ),
+    na.translate = na.translate,
+    drop = drop,
     ...
   )
 }
@@ -431,19 +466,24 @@ scale_fill_hypso_tint_c <- function(palette = "etopo1_hypso", ...,
                                     alpha = 1, direction = 1,
                                     values = NULL,
                                     limits = NULL,
-                                    na.value = NA,
+                                    na.value = "transparent",
                                     guide = "colourbar") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   # Use pal limits
   coltab <- tidyterra::hypsometric_tints_db
 
   if (!palette %in% coltab$pal) {
-    stop("'palette' does not match any given palette")
+    cli::cli_abort(paste(
+      "{.arg palette} {.val palette} does not match any given palette.",
+      "See {.help tidyterra::hypsometric_tints_db}"
+    ))
   }
 
   hypsocol <- coltab[coltab$pal == palette, ]
@@ -470,19 +510,24 @@ scale_colour_hypso_tint_c <- function(palette = "etopo1_hypso", ...,
                                       alpha = 1, direction = 1,
                                       values = NULL,
                                       limits = NULL,
-                                      na.value = NA,
+                                      na.value = "transparent",
                                       guide = "colourbar") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   # Use pal limits
   coltab <- tidyterra::hypsometric_tints_db
 
   if (!palette %in% coltab$pal) {
-    stop("'palette' does not match any given palette")
+    cli::cli_abort(paste(
+      "{.arg palette} {.val palette} does not match any given palette.",
+      "See {.help tidyterra::hypsometric_tints_db}"
+    ))
   }
 
   hypsocol <- coltab[coltab$pal == palette, ]
@@ -510,18 +555,24 @@ scale_fill_hypso_tint_b <- function(palette = "etopo1_hypso", ...,
                                     alpha = 1, direction = 1,
                                     values = NULL,
                                     limits = NULL,
-                                    na.value = NA, guide = "coloursteps") {
+                                    na.value = "transparent",
+                                    guide = "coloursteps") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   # Use pal limits
   coltab <- tidyterra::hypsometric_tints_db
 
   if (!palette %in% coltab$pal) {
-    stop("'palette' does not match any given palette")
+    cli::cli_abort(paste(
+      "{.arg palette} {.val palette} does not match any given palette.",
+      "See {.help tidyterra::hypsometric_tints_db}"
+    ))
   }
 
   hypsocol <- coltab[coltab$pal == palette, ]
@@ -549,18 +600,24 @@ scale_colour_hypso_tint_b <- function(palette = "etopo1_hypso", ...,
                                       alpha = 1, direction = 1,
                                       values = NULL,
                                       limits = NULL,
-                                      na.value = NA, guide = "coloursteps") {
+                                      na.value = "transparent",
+                                      guide = "coloursteps") {
   if (alpha < 0 || alpha > 1) {
-    stop("alpha level ", alpha, " not in [0,1]")
+    cli::cli_abort("{.arg alpha} {.field {alpha}} not in {.field [0,1]}")
   }
 
-  if (!direction %in% c(-1, 1)) stop("direction must be 1 or -1")
+  if (!direction %in% c(-1, 1)) {
+    cli::cli_abort("{.arg direction} must be {.field 1} or {.field -1}")
+  }
 
   # Use pal limits
   coltab <- tidyterra::hypsometric_tints_db
 
   if (!palette %in% coltab$pal) {
-    stop("'palette' does not match any given palette")
+    cli::cli_abort(paste(
+      "{.arg palette} {.val palette} does not match any given palette.",
+      "See {.help tidyterra::hypsometric_tints_db}"
+    ))
   }
 
   hypsocol <- coltab[coltab$pal == palette, ]
