@@ -16,7 +16,10 @@ as_spat_internal <- function(x) {
   }
 
 
-  cli::cli_abort("Can't convert x back to a Spat* object. Something went wrong")
+  cli::cli_abort(paste(
+    "Can't convert {.arg x} back to a {.cls Spat*} object.",
+    "Something went wrong"
+  ))
 }
 
 # Restore attributes from template
